"""Cmdlr infomation files."""

VERSION = (0, 1, 1)

VERSION_STR = '.'.join(map(lambda x: str(x), VERSION))
DESCRIPTION = 'Generate unoccupied name.'
LICENSE = 'MIT'
AUTHOR = 'visig'
AUTHOR_EMAIL = 'visig@protonmail.ch'
PROJECT_URL = 'https://github.com/civalin/unoccupied'
PROJECT_NAME = 'unoccupied'
